# API Reference

```{toctree}
:maxdepth: 1

api/plover
api/config
api/engine
api/exception
api/formatting
api/key_combo
api/log
api/machine
api/machine_keyboard_capture
api/machine_keymap
api/oslayer
api/orthography
api/output
api/registry
api/resource
api/steno
api/steno_dictionary
api/dictionary
api/suggestions
api/system
api/translation
api/qt
api/i18n
api/misc
api/plover_stroke
api/dictionary_lib
```
